import static org.junit.Assert.*;

import org.junit.Test;

/**
 * Unit tests for the Pikachu class.
 * 
 * To run this class as a JUnit test, go to the 'Run' drop down menu and
 * select 'Run As' -> 'JUnit Test'
 * 
 * @author David Mailhot
 *
 */
public class PikachuTest {

	/**
	 * Test that a higher level pokemon wins a battle.
	 */
	@Test
	public void testBattleHigherLevelWins() {
		Pokemon p1 = new Pikachu(6);
		Pokemon p2 = new Pikachu(5);
		int result = p1.battle(p2);
		
		// An equals assertion.  Compares the last 2 arguments.  If not equal,
		// this test case immediately fails and the given string is displayed.
		assertEquals(p1 + " should win against " + p2, 1, result);
	}
	
	/**
	 * Test that a lower level pokemon wins a battle.
	 */
	@Test
	public void testBattleLowerLevelLoses() {
		Pokemon p1 = new Pikachu(1);
		Pokemon p2 = new Pikachu(2);
		int result = p1.battle(p2);
		assertEquals(p1 + " should lose against " + p2, -1, result);
	}
	
	/**
	 * Test that equal level pokemon tie a battle.
	 */
	@Test
	public void testBattleEqualLevelTies() {
		Pokemon p1 = new Pikachu(10);
		Pokemon p2 = new Pikachu(10);
		int result = p1.battle(p2);
		assertEquals(p1 + " should tie against " + p2, 0, result);
	}
	
	/**
	 * Test that the winning pokemon levels up after battle.
	 */
	@Test
	public void testBattleWinnerLevelsUp() {
		Pokemon p1 = new Pikachu(4);
		Pokemon p2 = new Pikachu(2);
		
		int oldHpP1 = p1.getHp();
		int oldHpP2 = p2.getHp();
		
		p1.battle(p2);
		
		// A False assertion.  Evaluates the passed boolean expression.  
		// If it doesn't evaluate to false, this test case immediately fails
		// and the given string is displayed.
		assertFalse(p1 + " should have won, leveled up, and increased " +
				"its hp from its old value of "+oldHpP1, oldHpP1 == p1.getHp());

		// A True assertion.  Evaluates the passed boolean expression.  
		// If it doesn't evaluate to true, this test case immediately fails
		// and the given string is displayed.
		assertTrue(p2 + " should have lost, and NOT increased " +
				"its hp from its old value of "+oldHpP2, oldHpP1 == p1.getHp());
	}

}
