/**
 * <b>Pokemon</b> is an abstract class representing a pocket monster creature,
 * or a 'pokemon'.
 * <p>
 * A Pokemon can battle other types of Pokemon.  The winner is determined
 * by each Pokemon's hit points, or 'hp'.
 * <p>
 * A Pokemon has a numbered level, a number that increases as the Pokemon
 * gets experience battling.  When a Pokemon increases its level, its
 * hp increases as well.
 * <p>
 * 
 * @author David Mailhot
 */
public abstract class Pokemon {
	
	/** This Pokemon's current level */
	protected int level;
	
	/**
	 * This Pokemon battles the specified other Pokemon.
	 * 
	 * In a battle, the winning Pokemon is the Pokemon with the most hp.
	 * When a Pokemon wins a battle, it levels up.
	 * 
	 * @param other the Pokemon to battle.
	 * @return an int indicating who won the battle
	 * 		<blockquote>
	 * 		 1	if this Pokemon wins</br>
	 * 		-1	if the specified other Pokemon wins</br>
	 * 		</blockquote>
	 * @throws IllegalArgumentException if specified other is null.
	 */
	public int battle(Pokemon other) {
		if (other == null) {
			throw new IllegalArgumentException("specified other Pokemon must not be null.");
		}
		int myHp = this.getHp();
		int otherHp = other.getHp();
		
		if (myHp > otherHp) {
			other.levelUp();
			return 1;
		} else if (myHp < otherHp) {
			this.levelUp();
			return -1;
		} else {
			return 0;
		}
	}

	/**
	 * @return this Pokemon's current hp.
	 */
	public abstract int getHp();
	
	/**
	 * Causes this Pokemon to level up.
	 * 
	 * @modifies this Pokemon's level increases by one.
	 */
	private void levelUp() {
		this.level++;
	}
}
